@@ -2,7 +2,7 @@
   Xnee's Not an Event Emulator enables recording and replaying of X 
   protocol data
   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 
-                2007, 2008, 2009, 2010 Henrik Sandklef
+                2007, 2008, 2009, 2010, 2011 Henrik Sandklef
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -1724,17 +1724,16 @@ xnee_store_mouse_pos (xnee_data* xd )
   Window root;
   Window child;
   unsigned int mask;
-  Bool bo;
 
-  bo = XQueryPointer(xd->data,
-		     RootWindow(xd->data,0),
-		     &root,
-		     &child,
-		     &rx,
-		     &ry,
-		     &wx,
-		     &wy,
-		     &mask);
+  XQueryPointer(xd->data,
+		RootWindow(xd->data,0),
+		&root,
+		&child,
+		&rx,
+		&ry,
+		&wx,
+		&wy,
+		&mask);
   
   xd->data_fp (xd->out_file, 
 	       "%s " 
