@@ -3,11 +3,12 @@
  *                                                                    
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
+ *                      2009 Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
- * as published by the Free Software Foundation; either version 2    
+ * as published by the Free Software Foundation; either version 3    
  * of the License, or any later version.                             
  *                                                                   
  *                                                                   
@@ -25,8 +26,6 @@
 
 
 
-#include <X11/extensions/XTest.h>
-
 #include "libxnee/xnee.h"
 #include "libxnee/print.h"
 #include "libxnee/xnee_record.h"
@@ -53,17 +52,17 @@ xnee_set_callback (xnee_data *xd,
   callback_ptr saved;
   xnee_verbose ((xd, "\nTrying to set \"%s\" as callback\n", sym_name));
 
-  saved = *dest;
-
   if (xd==NULL)
     {
       return XNEE_NO_MAIN_DATA;
     }
   else
     {
-      *dest = (callback_ptr) xnee_dlsym(xd, 
-					xd->plugin_handle,
-					sym_name);
+      saved = *dest;
+
+      *(void**)(dest) =  xnee_dlsym(xd, 
+				    xd->plugin_handle,
+				    sym_name);
       error = xnee_dlerror(xd) ;
       if ( error != NULL)  
 	{
@@ -105,9 +104,9 @@ xnee_set_synchronize (xnee_data *xd,
     }
   else
     {
-      *dest = (synch_ptr) xnee_dlsym(xd, 
-				     xd->plugin_handle, 
-				     sym_name);
+      dest = (synch_ptrptr) xnee_dlsym(xd, 
+				       xd->plugin_handle, 
+				       (const char*)sym_name);
       
       if ((error = xnee_dlerror(xd)) != NULL)  
 	{
