@@ -3,7 +3,8 @@
  *                                                                    
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 2010 Henrik Sandklef  
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003,
+ *                      2010, 2011 Henrik Sandklef  
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -143,7 +144,6 @@ xnee_ungrab_keys (xnee_data* xd)
 int 
 xnee_grab_key (xnee_data* xd, int mode, char *key)
 {
-  int ret;
   int window;
   int screen;
   xnee_action_key ak;
@@ -194,7 +194,7 @@ xnee_grab_key (xnee_data* xd, int mode, char *key)
   xnee_verbose((xd, "screen   %d\n", screen));
 
 
-  ret = XGrabKey (xd->grab,  
+  XGrabKey (xd->grab,  
 	    ak.key,            
 	    AnyModifier,
 	    window,       
@@ -576,7 +576,7 @@ xnee_handle_grab_mouse(xnee_data *xd)
 static int
 xnee_handle_grab_key(xnee_data *xd, KeyCode kc, int mode)
 {
-  int ret ;
+  int ret = XNEE_OK;
 
 /*   xnee_set_verbose(xd); */
 
@@ -637,36 +637,20 @@ int
 xnee_save_or_print(xnee_data *xd, KeyCode kc, int mode)
 {
   int ret; 
-  KeySym ks ;
 
   xnee_verbose((xd, "---> xnee_save_or_print %d %d\n", kc, mode));
-  ks = XKeycodeToKeysym(xd->grab, kc, 0);
   
   if ( mode == XNEE_GRAB_MOUSE )
       {
 	xnee_verbose((xd, "--- xnee_save_or_print treat a mouse\n"));
 	ret = xnee_handle_grab_mouse(xd);
       }
-#ifdef USE_OBSOLETE
-    else if (IsModifierKey (ks))
-      {
-	xnee_verbose((xd, "--- xnee_save_or_print treat a modifier\n"));
-	ret = xnee_handle_grab_modifier(xd, kc, mode);
-      }
-#endif
   else
     {
       xnee_verbose((xd, "--- xnee_save_or_print treat an ordinary key\n")); 
       ret = xnee_handle_grab_key(xd, kc, mode); 
     }
 
-/*   if ( ret == XNEE_GRAB_DO_SAVE ) */
-/*     printf (" DO SAVE\n"); */
-/*   else if ( ret == XNEE_GRAB_DO_PRINT ) */
-/*     printf (" DO PRINT\n"); */
-/*   else if ( ret == XNEE_GRAB_DONT_PRINT ) */
-/*     printf (" DONT PRINT\n"); */
-
    xnee_verbose((xd, "<--- xnee_save_or_print %d\n", ret));
   return ret;
 }
